-------------------------------------------------- {COPYRIGHT-TOP-RM}
-- Licensed Materials - Property of IBM                              
--                                                                   
-- Restricted Materials of IBM                                       
--                                                                   
-- 5724-C51                                                          
--                                                                   
-- (C) Copyright IBM Corp. 1999,2004 All Rights Reserved.            
--                                                                   
-- US Government Users Restricted Rights - Use, duplication or       
-- disclosure restricted by GSA ADP Schedule Contract with           
-- IBM Corp.                                                         
-------------------------------------------------- {COPYRIGHT-END-RM}
-- File: archive/db/sql/procs/asisp_deleteoldnotes.sql, tbsm.sql, tbsm_base31e
-- SID: 1.2.4.11
-- Date Modified: 07/07/25 09:53:59
--
-- Module Description
--   Defines the asisp_deleteOldNotes stored procedure

USE Object
GO

---------------------------------------------------------------------------------------------------
-- asisp_deleteOldNotes
PRINT 'Creating procedure asisp_deleteOldNotes'
GO

IF EXISTS (SELECT * FROM sysobjects WHERE name = 'asisp_deleteOldNotes' AND type = 'P')
  DROP PROCEDURE asisp_deleteOldNotes
GO

-------------------------------------------------- {COPYRIGHT-TOP-RM}
-- Licensed Materials - Property of IBM                              
--                                                                   
-- Restricted Materials of IBM                                       
--                                                                   
-- 5724-C51                                                          
--                                                                   
-- (C) Copyright IBM Corp. 1999,2004 All Rights Reserved.            
--                                                                   
-- US Government Users Restricted Rights - Use, duplication or       
-- disclosure restricted by GSA ADP Schedule Contract with           
-- IBM Corp.                                                         
-------------------------------------------------- {COPYRIGHT-END-RM}
-- File: archive/db/sql/procs/asisp_deleteoldnotes.sql, tbsm.sql, tbsm_base31e
-- SID: 1.2.4.11
-- Date Modified: 07/07/25 09:53:59
--
-- Deletes closed notes older than a specified number of days
CREATE PROCEDURE asisp_deleteOldNotes
  @daysToKeep INT = 14,
  @limit INT = 1000,
  @trunc INT = 0       -- option to truncate ObjectStateHist table
                       -- set to 1 to truncate
AS
  DECLARE
    @steprc   INT,
    @steprc2  INT,
    @steprc3  INT,
    @steprc4  INT,
    @now      NVARCHAR(40),
    @rc2      INT,
    @rc       INT,
    @err      INT
  
  SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
  RAISERROR('%s: asisp_deleteOldNotes: Starting', 0, 1, @now) WITH NOWAIT

  SET NOCOUNT ON
  DELETE c FROM Note_C AS c JOIN Note_A AS a ON a.id = c.id 
  WHERE c.ctime < DATEADD(DAY, -@daysToKeep, CURRENT_TIMESTAMP) AND a._Status IN ('Closed', 'SystemClosed')
  SET @rc = @@ROWCOUNT

  SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
  RAISERROR('%s: asisp_deleteOldNotes: Deleted %d closed note(s) older than %d day(s)', 0, 1, @now, @rc, @daysToKeep) WITH NOWAIT

  -- Cleanup DeletedNoteDependent and DeletedOwnedEvent Tables
  SET ROWCOUNT @limit
  SET @rc2 = 1
  SET @steprc = 0
  WHILE @rc2 > 0
  BEGIN  
    DELETE FROM DeletedNoteDependent WHERE dtime < DATEADD(DAY, -@daysToKeep, CURRENT_TIMESTAMP) 
    SELECT @err = @@ERROR, @rc2 = @@ROWCOUNT
    IF @err <> 0
    BEGIN
      SET ROWCOUNT 0 -- reset the row limit
      SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
      RAISERROR('%s: asisp_deleteOldNotes: Failed to delete events from DeletedNoteDependent. Error=%d', 3, 1, @now, @err) WITH NOWAIT
      RETURN -30000
    END
    SET @steprc = @steprc + @rc2
    WAITFOR DELAY '00:00:05' -- Delay set to minimize contention and allow other procedures to process.
  END
  SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
  RAISERROR('%s: asisp_deleteOldNotes: %d row(s) deleted from DeletedNoteDependent table older than %d day(s)', 0, 1, @now, @steprc, @daysToKeep) WITH NOWAIT

  SET ROWCOUNT @limit
  SET @rc2 = 1
  SET @steprc2 = 0
  WHILE @rc2 > 0
  BEGIN  
    DELETE FROM DeletedOwnedEvent WHERE dtime < DATEADD(DAY, -@daysToKeep, CURRENT_TIMESTAMP) 
    SELECT @err = @@ERROR, @rc2 = @@ROWCOUNT
    IF @err <> 0
    BEGIN
      SET ROWCOUNT 0 -- reset the row limit
      SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
      RAISERROR('%s: asisp_deleteOldNotes: Failed to delete events from DeletedOwnedEvent. Error=%d', 3, 1, @now, @err) WITH NOWAIT
      RETURN -30000
    END
    SET @steprc2 = @steprc2 + @rc2
    WAITFOR DELAY '00:00:05' -- Delay set to minimize contention and allow other procedures to process.
  END
  SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
  RAISERROR('%s: asisp_deleteOldNotes: %d row(s) deleted from DeletedOwnedEvent table older than %d day(s)', 0, 1, @now, @steprc2, @daysToKeep) WITH NOWAIT

  -- OA21742 - Add cleanup of DeletedNote_C table
  SET ROWCOUNT @limit
  SET @rc2 = 1
  SET @steprc3 = 0
  WHILE @rc2 > 0
  BEGIN  
    DELETE FROM DeletedNote_C WHERE dtime < DATEADD(DAY, -@daysToKeep, CURRENT_TIMESTAMP) 
    SELECT @err = @@ERROR, @rc2 = @@ROWCOUNT
    IF @err <> 0
    BEGIN
      SET ROWCOUNT 0 -- reset the row limit
      SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
      RAISERROR('%s: asisp_deleteOldNotes: Failed to delete events from DeletedNote_C. Error=%d', 3, 1, @now, @err) WITH NOWAIT
      RETURN -30000
    END
    SET @steprc3 = @steprc3 + @rc2
    WAITFOR DELAY '00:00:02' -- Delay set to minimize contention and allow other procedures to process.
  END
  SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
  RAISERROR('%s: asisp_deleteOldNotes: %d row(s) deleted from DeletedNote_C table older than %d day(s)', 0, 1, @now, @steprc3, @daysToKeep) WITH NOWAIT

  -- OA21742 -  cleanup of ObjectStateHist table IF customer is not using TDW
  DECLARE @tdwReporting INT
  SELECT @tdwReporting = ISNULL(CAST(propertyvalue AS TINYINT), 0)
    FROM SystemConfiguration WHERE groupname = 'ReportingComponent' AND propertyname = 'TDWCrystal'
  IF @tdwReporting <> 1 OR @tdwReporting IS NULL
  BEGIN
    IF @trunc = 1
    BEGIN
      -- Option provided for customers who experience user impact with deletions
      TRUNCATE TABLE ObjectStateHist
      SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
      RAISERROR('%s: asisp_deleteOldNotes: Truncated ObjectStateHist table', 0, 1, @now) WITH NOWAIT
    END
    ELSE
    BEGIN
      IF @limit < 5000
        SET ROWCOUNT 5000
      ELSE
        SET ROWCOUNT @limit
      SET @rc2 = 1
      SET @steprc4 = 0
      WHILE @rc2 > 0
      BEGIN  
        DELETE FROM ObjectStateHist WHERE CTIME < DATEADD(DAY, -@daysToKeep, CURRENT_TIMESTAMP) 
        SELECT @err = @@ERROR, @rc2 = @@ROWCOUNT
        IF @err <> 0
        BEGIN
          SET ROWCOUNT 0 -- reset the row limit
          SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
          RAISERROR('%s: asisp_deleteOldNotes: Failed to delete events from ObjectStateHist. Error=%d', 3, 1, @now, @err) WITH NOWAIT
          RETURN -30000
        END
        SET @steprc4 = @steprc4 + @rc2
        WAITFOR DELAY '00:00:02' -- Delay set to minimize contention and allow other procedures to process.
      END
      SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
      RAISERROR('%s: asisp_deleteOldNotes: %d row(s) deleted from ObjectStateHist table older than %d day(s)', 0, 1, @now, @steprc4, @daysToKeep) WITH NOWAIT
    END
  END

  SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
  RAISERROR('%s: asisp_deleteOldNotes: Finished', 0, 1, @now) WITH NOWAIT

  SET ROWCOUNT 0
GO
