-------------------------------------------------- {COPYRIGHT-TOP-RM}
-- Licensed Materials - Property of IBM                              
--                                                                   
-- Restricted Materials of IBM                                       
--                                                                   
-- 5724-C51                                                          
--                                                                   
-- (C) Copyright IBM Corp. 1999,2004 All Rights Reserved.            
--                                                                   
-- US Government Users Restricted Rights - Use, duplication or       
-- disclosure restricted by GSA ADP Schedule Contract with           
-- IBM Corp.                                                         
-------------------------------------------------- {COPYRIGHT-END-RM}
-- File: archive/db/sql/procs/asisp_deleteoldobjectevents.sql, tbsm.sql, tbsm_base31e
-- SID: 1.1.4.6
-- Date Modified: 07/07/20 16:57:36
--
-- Module Description
--   Defines the asisp_deleteoldobjectevents stored procedure

USE Object
GO

---------------------------------------------------------------------------------------------------
-- asisp_deleteoldobjectevents
PRINT 'Creating procedure asisp_deleteoldobjectevents'
GO

IF EXISTS (SELECT * FROM sysobjects WHERE name = 'asisp_deleteoldobjectevents' AND type = 'P')
  DROP PROCEDURE asisp_deleteoldobjectevents
GO

-------------------------------------------------- {COPYRIGHT-TOP-RM}
-- Licensed Materials - Property of IBM                              
--                                                                   
-- Restricted Materials of IBM                                       
--                                                                   
-- 5724-C51                                                          
--                                                                   
-- (C) Copyright IBM Corp. 1999,2004 All Rights Reserved.            
--                                                                   
-- US Government Users Restricted Rights - Use, duplication or       
-- disclosure restricted by GSA ADP Schedule Contract with           
-- IBM Corp.                                                         
-------------------------------------------------- {COPYRIGHT-END-RM}
-- File: archive/db/sql/procs/asisp_deleteoldobjectevents.sql, tbsm.sql, tbsm_base31e
-- SID: 1.1.4.6
-- Date Modified: 07/07/20 16:57:36
CREATE PROCEDURE asisp_deleteoldobjectevents
  @daystokeep INT = 28,
  @limit INT = 5000
AS
  SET NOCOUNT ON

  DECLARE @oldest DATETIME
  SELECT @oldest = DATEADD(day, -@daystokeep, GETDATE())
  DELETE ARCBackupSessionMsg WHERE ARCMsgTime < @oldest
  DELETE ARCClientHostSummaryMsg WHERE ARCMsgTime < @oldest
  DELETE ARCStdErrMsg WHERE ARCMsgTime < @oldest
  DELETE ARCStdErrMsgEx WHERE StartTime < @oldest
  DELETE ASIMessageHeader WHERE SourceTime < @oldest

  -- OA21742 - Add cleanup of Acc1MsgInstance_C table
  -- The Acc1MsgInstance_A table cleanup will be handled by the 
  -- delete trigger on Acc1MsgInstance_C
  SET ROWCOUNT @limit
  DECLARE @rc INT, @steprc INT, @err INT, @now NVARCHAR(40)
  SET @rc = 1
  SET @steprc = 0
  WHILE @rc > 0
  BEGIN  
    DELETE FROM Acc1MsgInstance_C WHERE ctime < DATEADD(DAY, -@daystokeep, CURRENT_TIMESTAMP) 
    SELECT @err = @@ERROR, @rc = @@ROWCOUNT
    IF @err <> 0
    BEGIN
      SET ROWCOUNT 0 -- reset the row limit
      SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
      RAISERROR('%s: asisp_deleteoldobjectevents: Failed to delete events from Acc1MsgInstance_C. Error=%d', 3, 1, @now, @err) WITH NOWAIT
      RETURN -30000
    END
    SET @steprc = @steprc + @rc
    WAITFOR DELAY '00:00:02' -- Delay set to minimize contention and allow other procedures to process.
  END
  SET @now = CONVERT(NVARCHAR, CURRENT_TIMESTAMP, 121)
  RAISERROR('%s: asisp_deleteoldobjectevents: %d row(s) deleted from Acc1MsgInstance_C table older than %d day(s)', 0, 1, @now, @steprc, @daystokeep) WITH NOWAIT

  SET ROWCOUNT 0
GO
